# -*- coding: utf-8 -*-

from openerp import api, models


class EmailTemplate(models.Model):
    """ Extend generic message composition wizard to auto attach invoice
    related files when sending opening the Send Mail invoice button.
    """
    _inherit = 'email.template'

    @api.cr_uid_id_context
    def generate_email(self, cr, uid, template_id, res_id, context=None):
        """
        Generates an email from the template for given (model, res_id) pair.

       :param template_id: id of the template to render.
       :param res_id: id of the record to use for rendering the template (model
                      is taken from template definition)
       :returns: a dict containing all relevant fields for creating a new
                 mail.mail entry, with one extra key ``attachments``, in the
                 format expected by :py:meth:`mail_thread.message_post`.
        """
        att_obj = self.pool.get('ir.attachment')
        ir_model_data = self.pool.get('ir.model.data')

        reference_ids = []
        states = ['draft']
        data = {
            'account_voucher_email': 'email_template_account_voucher_email',
        }
        values = super(EmailTemplate, self).generate_email(
            cr, uid, template_id, res_id, context=context,
        )

        # Look for possible templates for invoice and override
        for module, name in data.iteritems():
            try:
                reference_ids.append(
                    ir_model_data.get_object_reference(
                        cr, uid, module, name,
                    )[1]
                )
            except ValueError:
                # Template not installed so we catch the error
                # and skip error messages
                continue

        if template_id in reference_ids:
            iatt_ids = att_obj.search(
                cr, uid,
                [
                    ('res_id', '=', res_id),
                    ('res_model', '=', 'account.voucher'),
                ],
                context=context,
            )
            attachments = []
            for iattach in att_obj.browse(cr, uid, iatt_ids, context=context):                
                ## Attach file to mesage
                attachments.append(iattach.id)#.file_xml_sign.id)                
            values['attachments'] = []
            values['attachment_ids'] = [(6, 0, attachments)]
        return values
